==> dpxu-1.0.0.tar.gz: dpxu/src/Form/SettingsForm.php <==
<?php

namespace Drupal\dpxu\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Component\Render\FormattableMarkup;

/**
 * Configure Designated Proxy User settings for this site.
 */
class SettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'dpxu_settings';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $form['dpxu_enabled'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Enable creation of managed user accounts'),
      '#description' => $this->t('Allows creation of new managed user accounts to be switched off without removing the module.'),
      '#default_value' => $this->config('dpxu.settings')->get('dpxu_enabled'),
    ];

    $fallback_max = 99;
    $saved_max = $this->config('dpxu.settings')->get('dpxu_max_users');
    $max_users = !empty($saved_max) ? $saved_max : $fallback_max;
    $form['dpxu_max_users'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Maximum number of user accounts per manager'),
      '#description' => $this->t('Maximum number of user accounts that can be attached to a manager account.'),
      '#default_value' => $max_users,
      '#size' => 12,
      '#maxlength' => 12,
    ];

    $fallback_message = $this->t('You have reached the maximum number of managed user accounts linked to your account. Please speak with an administrator.');
    $saved_message = $this->config('dpxu.settings')
      ->get('dpxu_max_user_message');
    $maxuser_message = !empty($saved_message) ? $saved_message : $fallback_message;
    $form['dpxu_max_user_message'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Message to display when manager reaches maximum number of managed user accounts linked to their account'),
      '#default_value' => $maxuser_message,
      '#size' => 255,
      '#maxlength' => 255,
    ];

    $form['dpxu_intercept_emails'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Reroute all emails for managed user accounts to their user manager'),
      '#description' => $this->t('Enable this if you would like all emails sent by the system to go to the user manager, even when the managed user has their own email address.'),
      '#default_value' => $this->config('dpxu.settings')
        ->get('dpxu_intercept_emails'),
    ];

    $fallback_notif = $this->config('system.site')->get('mail');
    $saved_notif = $this->config('dpxu.settings')->get('dpxu_fallback_email');
    $contact_notif = !empty($saved_notif) ? $saved_notif : $fallback_notif;
    $form['dpxu_fallback_email'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Fallback email address'),
      '#description' => $this->t('Email address to send manager notifications to when a managed user is not assigned to a manager.'),
      '#default_value' => $contact_notif,
      '#size' => 255,
      '#maxlength' => 255,
    ];

    $form['dpxu_generate_emails'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Provide generic placeholder email addresses for managed user accounts without emails'),
      '#description' => $this->t('Although Drupal allows accounts to be created without an email address, some parts of the core system and contrib modules may not work as expected without a valid email address attached to the account. This setting generates a generic, technically valid, but undeliverable email address if the email address field is left blank on account creation, so that managed users do not encounter such errors.'),
      '#default_value' => $this->config('dpxu.settings')
        ->get('dpxu_generate_emails'),
    ];

    $contact_config = $this->config('dpxu.settings')
      ->get('dpxu_contact_template');

    $contact_placeholders = new FormattableMarkup(
      "<pre>
[dpxu:manager:fullname]&#9;&#9;The manager user's full name
[dpxu:user:fullname]&#9;&#9;The user's full name
[dpxu:user:edit]&#9;&#9;The link to edit the user account
[dpxu:message:content]&#9;&#9;The content of the message from the user</pre>", []);

    $form['dpxu_contact_template'] = [
      '#type' => 'text_format',
      '#title' => $this->t('Template for the email sent to a user manager when a managed user sends a message via the contact form'),
      '#format' => $contact_config['format'] ?? 'basic_html',
      '#default_value' => $contact_config['value'] ?? '',
      '#description' => $this->t("The following placeholder tokens are available for this field: @placeholders", ['@placeholders' => $contact_placeholders]),
    ];

    $intercept_config = $this->config('dpxu.settings')
      ->get('dpxu_intercept_template');

    $intercept_placeholders = new FormattableMarkup(
      "<pre>
[dpxu:manager:fullname]&#9;&#9;The manager user's full name
[dpxu:user:fullname]&#9;&#9;The user's full name
[dpxu:user:edit]&#9;&#9;The link to edit the user account
[dpxu:notification:content]&#9;The content of the notification sent to the user</pre>", []);

    $form['dpxu_intercept_template'] = [
      '#type' => 'text_format',
      '#title' => $this->t('Template for the notification sent to a user manager when an email for the managed user is rerouted to them'),
      '#format' => $intercept_config['format'] ?? 'basic_html',
      '#default_value' => $intercept_config['value'] ?? '',
      '#description' => $this->t("The following placeholder tokens are available for this field: @placeholders", ['@placeholders' => $intercept_placeholders]),
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $this->config('dpxu.settings')
      ->set('dpxu_enabled', $form_state->getValue('dpxu_enabled'))
      ->set('dpxu_max_users', $form_state->getValue('dpxu_max_users'))
      ->set('dpxu_max_user_message', $form_state->getValue('dpxu_max_user_message'))
      ->set('dpxu_fallback_email', $form_state->getValue('dpxu_fallback_email'))
      ->set('dpxu_contact_template', $form_state->getValue('dpxu_contact_template'))
      ->set('dpxu_intercept_template', $form_state->getValue('dpxu_intercept_template'))
      ->set('dpxu_intercept_emails', $form_state->getValue('dpxu_intercept_emails'))
      ->set('dpxu_generate_emails', $form_state->getValue('dpxu_generate_emails'))
      ->save();
    parent::submitForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['dpxu.settings'];
  }

}

==> dpxu-1.0.3.tar.gz: dpxu/src/Form/SettingsForm.php <==
<?php

namespace Drupal\dpxu\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Component\Render\FormattableMarkup;

/**
 * Configure Designated Proxy User settings for this site.
 */
class SettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'dpxu_settings';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $form['dpxu_enabled'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Enable creation of managed user accounts'),
      '#description' => $this->t('Allows creation of new managed user accounts to be switched off without removing the module.'),
      '#default_value' => $this->config('dpxu.settings')->get('dpxu_enabled'),
    ];

    $fallback_max = 99;
    $saved_max = $this->config('dpxu.settings')->get('dpxu_max_users');
    $max_users = !empty($saved_max) ? $saved_max : $fallback_max;
    $form['dpxu_max_users'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Maximum number of user accounts per manager'),
      '#description' => $this->t('Maximum number of user accounts that can be attached to a manager account.'),
      '#default_value' => $max_users,
      '#size' => 12,
      '#maxlength' => 12,
    ];

    $fallback_message = $this->t('You have reached the maximum number of managed user accounts linked to your account. Please speak with an administrator.');
    $saved_message = $this->config('dpxu.settings')
      ->get('dpxu_max_user_message');
    $max_user_message = !empty($saved_message) ? $saved_message : $fallback_message;
    $form['dpxu_max_user_message'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Message to display when manager reaches maximum number of managed user accounts linked to their account'),
      '#default_value' => $max_user_message,
      '#size' => 255,
      '#maxlength' => 255,
    ];

    $form['dpxu_intercept_emails'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Reroute all emails for managed user accounts to their user manager'),
      '#description' => $this->t('Enable this if you would like all emails sent by the system to go to the user manager, even when the managed user has their own email address.'),
      '#default_value' => $this->config('dpxu.settings')
        ->get('dpxu_intercept_emails'),
    ];

    $fallback_notify = $this->config('system.site')->get('mail');
    $saved_notify = $this->config('dpxu.settings')->get('dpxu_fallback_email');
    $contact_notify = !empty($saved_notify) ? $saved_notify : $fallback_notify;
    $form['dpxu_fallback_email'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Fallback email address'),
      '#description' => $this->t('Email address to send manager notifications to when a managed user is not assigned to a manager.'),
      '#default_value' => $contact_notify,
      '#size' => 255,
      '#maxlength' => 255,
    ];

    $form['dpxu_generate_emails'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Provide generic placeholder email addresses for managed user accounts without emails'),
      '#description' => $this->t('Although Drupal allows accounts to be created without an email address, some parts of the core system and contrib modules may not work as expected without a valid email address attached to the account. This setting generates a generic, technically valid, but undeliverable email address if the email address field is left blank on account creation, so that managed users do not encounter such errors.'),
      '#default_value' => $this->config('dpxu.settings')
        ->get('dpxu_generate_emails'),
    ];

    $contact_config = $this->config('dpxu.settings')
      ->get('dpxu_contact_template');

    $contact_placeholders = new FormattableMarkup(
      "<pre>
[dpxu:manager:fullname]&#9;&#9;The manager user's full name
[dpxu:user:fullname]&#9;&#9;The user's full name
[dpxu:user:edit]&#9;&#9;The link to edit the user account
[dpxu:message:content]&#9;&#9;The content of the message from the user</pre>", []);

    $form['dpxu_contact_template'] = [
      '#type' => 'text_format',
      '#title' => $this->t('Template for the email sent to a user manager when a managed user sends a message via the contact form'),
      '#format' => $contact_config['format'] ?? 'basic_html',
      '#default_value' => $contact_config['value'] ?? '',
      '#description' => $this->t("The following placeholder tokens are available for this field: @placeholders", ['@placeholders' => $contact_placeholders]),
    ];

    $intercept_config = $this->config('dpxu.settings')
      ->get('dpxu_intercept_template');

    $intercept_placeholders = new FormattableMarkup(
      "<pre>
[dpxu:manager:fullname]&#9;&#9;The manager user's full name
[dpxu:user:fullname]&#9;&#9;The user's full name
[dpxu:user:edit]&#9;&#9;The link to edit the user account
[dpxu:notification:content]&#9;The content of the notification sent to the user</pre>", []);

    $form['dpxu_intercept_template'] = [
      '#type' => 'text_format',
      '#title' => $this->t('Template for the notification sent to a user manager when an email for the managed user is rerouted to them'),
      '#format' => $intercept_config['format'] ?? 'basic_html',
      '#default_value' => $intercept_config['value'] ?? '',
      '#description' => $this->t("The following placeholder tokens are available for this field: @placeholders", ['@placeholders' => $intercept_placeholders]),
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $this->config('dpxu.settings')
      ->set('dpxu_enabled', $form_state->getValue('dpxu_enabled'))
      ->set('dpxu_max_users', $form_state->getValue('dpxu_max_users'))
      ->set('dpxu_max_user_message', $form_state->getValue('dpxu_max_user_message'))
      ->set('dpxu_fallback_email', $form_state->getValue('dpxu_fallback_email'))
      ->set('dpxu_contact_template', $form_state->getValue('dpxu_contact_template'))
      ->set('dpxu_intercept_template', $form_state->getValue('dpxu_intercept_template'))
      ->set('dpxu_intercept_emails', $form_state->getValue('dpxu_intercept_emails'))
      ->set('dpxu_generate_emails', $form_state->getValue('dpxu_generate_emails'))
      ->save();
    parent::submitForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['dpxu.settings'];
  }

}
